"""__init__.py"""

import sys
from typing import TYPE_CHECKING

from lazy_imports import LazyImporter


if TYPE_CHECKING:
    from ._3245 import AbstractAssemblySteadyStateSynchronousResponseOnAShaft
    from ._3246 import AbstractShaftOrHousingSteadyStateSynchronousResponseOnAShaft
    from ._3247 import AbstractShaftSteadyStateSynchronousResponseOnAShaft
    from ._3248 import (
        AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from ._3249 import AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._3250 import AGMAGleasonConicalGearSetSteadyStateSynchronousResponseOnAShaft
    from ._3251 import AGMAGleasonConicalGearSteadyStateSynchronousResponseOnAShaft
    from ._3252 import AssemblySteadyStateSynchronousResponseOnAShaft
    from ._3253 import BearingSteadyStateSynchronousResponseOnAShaft
    from ._3254 import BeltConnectionSteadyStateSynchronousResponseOnAShaft
    from ._3255 import BeltDriveSteadyStateSynchronousResponseOnAShaft
    from ._3256 import BevelDifferentialGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._3257 import BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft
    from ._3258 import BevelDifferentialGearSteadyStateSynchronousResponseOnAShaft
    from ._3259 import BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft
    from ._3260 import BevelDifferentialSunGearSteadyStateSynchronousResponseOnAShaft
    from ._3261 import BevelGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._3262 import BevelGearSetSteadyStateSynchronousResponseOnAShaft
    from ._3263 import BevelGearSteadyStateSynchronousResponseOnAShaft
    from ._3264 import BoltedJointSteadyStateSynchronousResponseOnAShaft
    from ._3265 import BoltSteadyStateSynchronousResponseOnAShaft
    from ._3266 import ClutchConnectionSteadyStateSynchronousResponseOnAShaft
    from ._3267 import ClutchHalfSteadyStateSynchronousResponseOnAShaft
    from ._3268 import ClutchSteadyStateSynchronousResponseOnAShaft
    from ._3269 import CoaxialConnectionSteadyStateSynchronousResponseOnAShaft
    from ._3270 import ComponentSteadyStateSynchronousResponseOnAShaft
    from ._3271 import ConceptCouplingConnectionSteadyStateSynchronousResponseOnAShaft
    from ._3272 import ConceptCouplingHalfSteadyStateSynchronousResponseOnAShaft
    from ._3273 import ConceptCouplingSteadyStateSynchronousResponseOnAShaft
    from ._3274 import ConceptGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._3275 import ConceptGearSetSteadyStateSynchronousResponseOnAShaft
    from ._3276 import ConceptGearSteadyStateSynchronousResponseOnAShaft
    from ._3277 import ConicalGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._3278 import ConicalGearSetSteadyStateSynchronousResponseOnAShaft
    from ._3279 import ConicalGearSteadyStateSynchronousResponseOnAShaft
    from ._3280 import ConnectionSteadyStateSynchronousResponseOnAShaft
    from ._3281 import ConnectorSteadyStateSynchronousResponseOnAShaft
    from ._3282 import CouplingConnectionSteadyStateSynchronousResponseOnAShaft
    from ._3283 import CouplingHalfSteadyStateSynchronousResponseOnAShaft
    from ._3284 import CouplingSteadyStateSynchronousResponseOnAShaft
    from ._3285 import CVTBeltConnectionSteadyStateSynchronousResponseOnAShaft
    from ._3286 import CVTPulleySteadyStateSynchronousResponseOnAShaft
    from ._3287 import CVTSteadyStateSynchronousResponseOnAShaft
    from ._3288 import CycloidalAssemblySteadyStateSynchronousResponseOnAShaft
    from ._3289 import (
        CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from ._3290 import (
        CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from ._3291 import CycloidalDiscSteadyStateSynchronousResponseOnAShaft
    from ._3292 import CylindricalGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._3293 import CylindricalGearSetSteadyStateSynchronousResponseOnAShaft
    from ._3294 import CylindricalGearSteadyStateSynchronousResponseOnAShaft
    from ._3295 import CylindricalPlanetGearSteadyStateSynchronousResponseOnAShaft
    from ._3296 import DatumSteadyStateSynchronousResponseOnAShaft
    from ._3297 import ExternalCADModelSteadyStateSynchronousResponseOnAShaft
    from ._3298 import FaceGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._3299 import FaceGearSetSteadyStateSynchronousResponseOnAShaft
    from ._3300 import FaceGearSteadyStateSynchronousResponseOnAShaft
    from ._3301 import FEPartSteadyStateSynchronousResponseOnAShaft
    from ._3302 import FlexiblePinAssemblySteadyStateSynchronousResponseOnAShaft
    from ._3303 import GearMeshSteadyStateSynchronousResponseOnAShaft
    from ._3304 import GearSetSteadyStateSynchronousResponseOnAShaft
    from ._3305 import GearSteadyStateSynchronousResponseOnAShaft
    from ._3306 import GuideDxfModelSteadyStateSynchronousResponseOnAShaft
    from ._3307 import HypoidGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._3308 import HypoidGearSetSteadyStateSynchronousResponseOnAShaft
    from ._3309 import HypoidGearSteadyStateSynchronousResponseOnAShaft
    from ._3310 import (
        InterMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from ._3311 import (
        KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from ._3312 import (
        KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from ._3313 import (
        KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseOnAShaft,
    )
    from ._3314 import (
        KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from ._3315 import (
        KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from ._3316 import (
        KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseOnAShaft,
    )
    from ._3317 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft,
    )
    from ._3318 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft,
    )
    from ._3319 import (
        KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseOnAShaft,
    )
    from ._3320 import MassDiscSteadyStateSynchronousResponseOnAShaft
    from ._3321 import MeasurementComponentSteadyStateSynchronousResponseOnAShaft
    from ._3322 import MountableComponentSteadyStateSynchronousResponseOnAShaft
    from ._3323 import OilSealSteadyStateSynchronousResponseOnAShaft
    from ._3324 import PartSteadyStateSynchronousResponseOnAShaft
    from ._3325 import (
        PartToPartShearCouplingConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from ._3326 import PartToPartShearCouplingHalfSteadyStateSynchronousResponseOnAShaft
    from ._3327 import PartToPartShearCouplingSteadyStateSynchronousResponseOnAShaft
    from ._3328 import PlanetaryConnectionSteadyStateSynchronousResponseOnAShaft
    from ._3329 import PlanetaryGearSetSteadyStateSynchronousResponseOnAShaft
    from ._3330 import PlanetCarrierSteadyStateSynchronousResponseOnAShaft
    from ._3331 import PointLoadSteadyStateSynchronousResponseOnAShaft
    from ._3332 import PowerLoadSteadyStateSynchronousResponseOnAShaft
    from ._3333 import PulleySteadyStateSynchronousResponseOnAShaft
    from ._3334 import RingPinsSteadyStateSynchronousResponseOnAShaft
    from ._3335 import RingPinsToDiscConnectionSteadyStateSynchronousResponseOnAShaft
    from ._3336 import RollingRingAssemblySteadyStateSynchronousResponseOnAShaft
    from ._3337 import RollingRingConnectionSteadyStateSynchronousResponseOnAShaft
    from ._3338 import RollingRingSteadyStateSynchronousResponseOnAShaft
    from ._3339 import RootAssemblySteadyStateSynchronousResponseOnAShaft
    from ._3340 import ShaftHubConnectionSteadyStateSynchronousResponseOnAShaft
    from ._3341 import ShaftSteadyStateSynchronousResponseOnAShaft
    from ._3342 import (
        ShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft,
    )
    from ._3343 import SpecialisedAssemblySteadyStateSynchronousResponseOnAShaft
    from ._3344 import SpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._3345 import SpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft
    from ._3346 import SpiralBevelGearSteadyStateSynchronousResponseOnAShaft
    from ._3347 import SpringDamperConnectionSteadyStateSynchronousResponseOnAShaft
    from ._3348 import SpringDamperHalfSteadyStateSynchronousResponseOnAShaft
    from ._3349 import SpringDamperSteadyStateSynchronousResponseOnAShaft
    from ._3350 import SteadyStateSynchronousResponseOnAShaft
    from ._3351 import StraightBevelDiffGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._3352 import StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft
    from ._3353 import StraightBevelDiffGearSteadyStateSynchronousResponseOnAShaft
    from ._3354 import StraightBevelGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._3355 import StraightBevelGearSetSteadyStateSynchronousResponseOnAShaft
    from ._3356 import StraightBevelGearSteadyStateSynchronousResponseOnAShaft
    from ._3357 import StraightBevelPlanetGearSteadyStateSynchronousResponseOnAShaft
    from ._3358 import StraightBevelSunGearSteadyStateSynchronousResponseOnAShaft
    from ._3359 import SynchroniserHalfSteadyStateSynchronousResponseOnAShaft
    from ._3360 import SynchroniserPartSteadyStateSynchronousResponseOnAShaft
    from ._3361 import SynchroniserSleeveSteadyStateSynchronousResponseOnAShaft
    from ._3362 import SynchroniserSteadyStateSynchronousResponseOnAShaft
    from ._3363 import TorqueConverterConnectionSteadyStateSynchronousResponseOnAShaft
    from ._3364 import TorqueConverterPumpSteadyStateSynchronousResponseOnAShaft
    from ._3365 import TorqueConverterSteadyStateSynchronousResponseOnAShaft
    from ._3366 import TorqueConverterTurbineSteadyStateSynchronousResponseOnAShaft
    from ._3367 import UnbalancedMassSteadyStateSynchronousResponseOnAShaft
    from ._3368 import VirtualComponentSteadyStateSynchronousResponseOnAShaft
    from ._3369 import WormGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._3370 import WormGearSetSteadyStateSynchronousResponseOnAShaft
    from ._3371 import WormGearSteadyStateSynchronousResponseOnAShaft
    from ._3372 import ZerolBevelGearMeshSteadyStateSynchronousResponseOnAShaft
    from ._3373 import ZerolBevelGearSetSteadyStateSynchronousResponseOnAShaft
    from ._3374 import ZerolBevelGearSteadyStateSynchronousResponseOnAShaft
else:
    import_structure = {
        "_3245": ["AbstractAssemblySteadyStateSynchronousResponseOnAShaft"],
        "_3246": ["AbstractShaftOrHousingSteadyStateSynchronousResponseOnAShaft"],
        "_3247": ["AbstractShaftSteadyStateSynchronousResponseOnAShaft"],
        "_3248": [
            "AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_3249": ["AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseOnAShaft"],
        "_3250": ["AGMAGleasonConicalGearSetSteadyStateSynchronousResponseOnAShaft"],
        "_3251": ["AGMAGleasonConicalGearSteadyStateSynchronousResponseOnAShaft"],
        "_3252": ["AssemblySteadyStateSynchronousResponseOnAShaft"],
        "_3253": ["BearingSteadyStateSynchronousResponseOnAShaft"],
        "_3254": ["BeltConnectionSteadyStateSynchronousResponseOnAShaft"],
        "_3255": ["BeltDriveSteadyStateSynchronousResponseOnAShaft"],
        "_3256": ["BevelDifferentialGearMeshSteadyStateSynchronousResponseOnAShaft"],
        "_3257": ["BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft"],
        "_3258": ["BevelDifferentialGearSteadyStateSynchronousResponseOnAShaft"],
        "_3259": ["BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft"],
        "_3260": ["BevelDifferentialSunGearSteadyStateSynchronousResponseOnAShaft"],
        "_3261": ["BevelGearMeshSteadyStateSynchronousResponseOnAShaft"],
        "_3262": ["BevelGearSetSteadyStateSynchronousResponseOnAShaft"],
        "_3263": ["BevelGearSteadyStateSynchronousResponseOnAShaft"],
        "_3264": ["BoltedJointSteadyStateSynchronousResponseOnAShaft"],
        "_3265": ["BoltSteadyStateSynchronousResponseOnAShaft"],
        "_3266": ["ClutchConnectionSteadyStateSynchronousResponseOnAShaft"],
        "_3267": ["ClutchHalfSteadyStateSynchronousResponseOnAShaft"],
        "_3268": ["ClutchSteadyStateSynchronousResponseOnAShaft"],
        "_3269": ["CoaxialConnectionSteadyStateSynchronousResponseOnAShaft"],
        "_3270": ["ComponentSteadyStateSynchronousResponseOnAShaft"],
        "_3271": ["ConceptCouplingConnectionSteadyStateSynchronousResponseOnAShaft"],
        "_3272": ["ConceptCouplingHalfSteadyStateSynchronousResponseOnAShaft"],
        "_3273": ["ConceptCouplingSteadyStateSynchronousResponseOnAShaft"],
        "_3274": ["ConceptGearMeshSteadyStateSynchronousResponseOnAShaft"],
        "_3275": ["ConceptGearSetSteadyStateSynchronousResponseOnAShaft"],
        "_3276": ["ConceptGearSteadyStateSynchronousResponseOnAShaft"],
        "_3277": ["ConicalGearMeshSteadyStateSynchronousResponseOnAShaft"],
        "_3278": ["ConicalGearSetSteadyStateSynchronousResponseOnAShaft"],
        "_3279": ["ConicalGearSteadyStateSynchronousResponseOnAShaft"],
        "_3280": ["ConnectionSteadyStateSynchronousResponseOnAShaft"],
        "_3281": ["ConnectorSteadyStateSynchronousResponseOnAShaft"],
        "_3282": ["CouplingConnectionSteadyStateSynchronousResponseOnAShaft"],
        "_3283": ["CouplingHalfSteadyStateSynchronousResponseOnAShaft"],
        "_3284": ["CouplingSteadyStateSynchronousResponseOnAShaft"],
        "_3285": ["CVTBeltConnectionSteadyStateSynchronousResponseOnAShaft"],
        "_3286": ["CVTPulleySteadyStateSynchronousResponseOnAShaft"],
        "_3287": ["CVTSteadyStateSynchronousResponseOnAShaft"],
        "_3288": ["CycloidalAssemblySteadyStateSynchronousResponseOnAShaft"],
        "_3289": [
            "CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_3290": [
            "CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_3291": ["CycloidalDiscSteadyStateSynchronousResponseOnAShaft"],
        "_3292": ["CylindricalGearMeshSteadyStateSynchronousResponseOnAShaft"],
        "_3293": ["CylindricalGearSetSteadyStateSynchronousResponseOnAShaft"],
        "_3294": ["CylindricalGearSteadyStateSynchronousResponseOnAShaft"],
        "_3295": ["CylindricalPlanetGearSteadyStateSynchronousResponseOnAShaft"],
        "_3296": ["DatumSteadyStateSynchronousResponseOnAShaft"],
        "_3297": ["ExternalCADModelSteadyStateSynchronousResponseOnAShaft"],
        "_3298": ["FaceGearMeshSteadyStateSynchronousResponseOnAShaft"],
        "_3299": ["FaceGearSetSteadyStateSynchronousResponseOnAShaft"],
        "_3300": ["FaceGearSteadyStateSynchronousResponseOnAShaft"],
        "_3301": ["FEPartSteadyStateSynchronousResponseOnAShaft"],
        "_3302": ["FlexiblePinAssemblySteadyStateSynchronousResponseOnAShaft"],
        "_3303": ["GearMeshSteadyStateSynchronousResponseOnAShaft"],
        "_3304": ["GearSetSteadyStateSynchronousResponseOnAShaft"],
        "_3305": ["GearSteadyStateSynchronousResponseOnAShaft"],
        "_3306": ["GuideDxfModelSteadyStateSynchronousResponseOnAShaft"],
        "_3307": ["HypoidGearMeshSteadyStateSynchronousResponseOnAShaft"],
        "_3308": ["HypoidGearSetSteadyStateSynchronousResponseOnAShaft"],
        "_3309": ["HypoidGearSteadyStateSynchronousResponseOnAShaft"],
        "_3310": [
            "InterMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_3311": [
            "KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_3312": [
            "KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_3313": [
            "KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_3314": [
            "KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_3315": [
            "KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_3316": [
            "KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_3317": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft"
        ],
        "_3318": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft"
        ],
        "_3319": [
            "KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseOnAShaft"
        ],
        "_3320": ["MassDiscSteadyStateSynchronousResponseOnAShaft"],
        "_3321": ["MeasurementComponentSteadyStateSynchronousResponseOnAShaft"],
        "_3322": ["MountableComponentSteadyStateSynchronousResponseOnAShaft"],
        "_3323": ["OilSealSteadyStateSynchronousResponseOnAShaft"],
        "_3324": ["PartSteadyStateSynchronousResponseOnAShaft"],
        "_3325": [
            "PartToPartShearCouplingConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_3326": ["PartToPartShearCouplingHalfSteadyStateSynchronousResponseOnAShaft"],
        "_3327": ["PartToPartShearCouplingSteadyStateSynchronousResponseOnAShaft"],
        "_3328": ["PlanetaryConnectionSteadyStateSynchronousResponseOnAShaft"],
        "_3329": ["PlanetaryGearSetSteadyStateSynchronousResponseOnAShaft"],
        "_3330": ["PlanetCarrierSteadyStateSynchronousResponseOnAShaft"],
        "_3331": ["PointLoadSteadyStateSynchronousResponseOnAShaft"],
        "_3332": ["PowerLoadSteadyStateSynchronousResponseOnAShaft"],
        "_3333": ["PulleySteadyStateSynchronousResponseOnAShaft"],
        "_3334": ["RingPinsSteadyStateSynchronousResponseOnAShaft"],
        "_3335": ["RingPinsToDiscConnectionSteadyStateSynchronousResponseOnAShaft"],
        "_3336": ["RollingRingAssemblySteadyStateSynchronousResponseOnAShaft"],
        "_3337": ["RollingRingConnectionSteadyStateSynchronousResponseOnAShaft"],
        "_3338": ["RollingRingSteadyStateSynchronousResponseOnAShaft"],
        "_3339": ["RootAssemblySteadyStateSynchronousResponseOnAShaft"],
        "_3340": ["ShaftHubConnectionSteadyStateSynchronousResponseOnAShaft"],
        "_3341": ["ShaftSteadyStateSynchronousResponseOnAShaft"],
        "_3342": [
            "ShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft"
        ],
        "_3343": ["SpecialisedAssemblySteadyStateSynchronousResponseOnAShaft"],
        "_3344": ["SpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft"],
        "_3345": ["SpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft"],
        "_3346": ["SpiralBevelGearSteadyStateSynchronousResponseOnAShaft"],
        "_3347": ["SpringDamperConnectionSteadyStateSynchronousResponseOnAShaft"],
        "_3348": ["SpringDamperHalfSteadyStateSynchronousResponseOnAShaft"],
        "_3349": ["SpringDamperSteadyStateSynchronousResponseOnAShaft"],
        "_3350": ["SteadyStateSynchronousResponseOnAShaft"],
        "_3351": ["StraightBevelDiffGearMeshSteadyStateSynchronousResponseOnAShaft"],
        "_3352": ["StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft"],
        "_3353": ["StraightBevelDiffGearSteadyStateSynchronousResponseOnAShaft"],
        "_3354": ["StraightBevelGearMeshSteadyStateSynchronousResponseOnAShaft"],
        "_3355": ["StraightBevelGearSetSteadyStateSynchronousResponseOnAShaft"],
        "_3356": ["StraightBevelGearSteadyStateSynchronousResponseOnAShaft"],
        "_3357": ["StraightBevelPlanetGearSteadyStateSynchronousResponseOnAShaft"],
        "_3358": ["StraightBevelSunGearSteadyStateSynchronousResponseOnAShaft"],
        "_3359": ["SynchroniserHalfSteadyStateSynchronousResponseOnAShaft"],
        "_3360": ["SynchroniserPartSteadyStateSynchronousResponseOnAShaft"],
        "_3361": ["SynchroniserSleeveSteadyStateSynchronousResponseOnAShaft"],
        "_3362": ["SynchroniserSteadyStateSynchronousResponseOnAShaft"],
        "_3363": ["TorqueConverterConnectionSteadyStateSynchronousResponseOnAShaft"],
        "_3364": ["TorqueConverterPumpSteadyStateSynchronousResponseOnAShaft"],
        "_3365": ["TorqueConverterSteadyStateSynchronousResponseOnAShaft"],
        "_3366": ["TorqueConverterTurbineSteadyStateSynchronousResponseOnAShaft"],
        "_3367": ["UnbalancedMassSteadyStateSynchronousResponseOnAShaft"],
        "_3368": ["VirtualComponentSteadyStateSynchronousResponseOnAShaft"],
        "_3369": ["WormGearMeshSteadyStateSynchronousResponseOnAShaft"],
        "_3370": ["WormGearSetSteadyStateSynchronousResponseOnAShaft"],
        "_3371": ["WormGearSteadyStateSynchronousResponseOnAShaft"],
        "_3372": ["ZerolBevelGearMeshSteadyStateSynchronousResponseOnAShaft"],
        "_3373": ["ZerolBevelGearSetSteadyStateSynchronousResponseOnAShaft"],
        "_3374": ["ZerolBevelGearSteadyStateSynchronousResponseOnAShaft"],
    }

    sys.modules[__name__] = LazyImporter(
        __name__,
        globals()["__file__"],
        import_structure,
    )

__all__ = (
    "AbstractAssemblySteadyStateSynchronousResponseOnAShaft",
    "AbstractShaftOrHousingSteadyStateSynchronousResponseOnAShaft",
    "AbstractShaftSteadyStateSynchronousResponseOnAShaft",
    "AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft",
    "AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseOnAShaft",
    "AGMAGleasonConicalGearSetSteadyStateSynchronousResponseOnAShaft",
    "AGMAGleasonConicalGearSteadyStateSynchronousResponseOnAShaft",
    "AssemblySteadyStateSynchronousResponseOnAShaft",
    "BearingSteadyStateSynchronousResponseOnAShaft",
    "BeltConnectionSteadyStateSynchronousResponseOnAShaft",
    "BeltDriveSteadyStateSynchronousResponseOnAShaft",
    "BevelDifferentialGearMeshSteadyStateSynchronousResponseOnAShaft",
    "BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft",
    "BevelDifferentialGearSteadyStateSynchronousResponseOnAShaft",
    "BevelDifferentialPlanetGearSteadyStateSynchronousResponseOnAShaft",
    "BevelDifferentialSunGearSteadyStateSynchronousResponseOnAShaft",
    "BevelGearMeshSteadyStateSynchronousResponseOnAShaft",
    "BevelGearSetSteadyStateSynchronousResponseOnAShaft",
    "BevelGearSteadyStateSynchronousResponseOnAShaft",
    "BoltedJointSteadyStateSynchronousResponseOnAShaft",
    "BoltSteadyStateSynchronousResponseOnAShaft",
    "ClutchConnectionSteadyStateSynchronousResponseOnAShaft",
    "ClutchHalfSteadyStateSynchronousResponseOnAShaft",
    "ClutchSteadyStateSynchronousResponseOnAShaft",
    "CoaxialConnectionSteadyStateSynchronousResponseOnAShaft",
    "ComponentSteadyStateSynchronousResponseOnAShaft",
    "ConceptCouplingConnectionSteadyStateSynchronousResponseOnAShaft",
    "ConceptCouplingHalfSteadyStateSynchronousResponseOnAShaft",
    "ConceptCouplingSteadyStateSynchronousResponseOnAShaft",
    "ConceptGearMeshSteadyStateSynchronousResponseOnAShaft",
    "ConceptGearSetSteadyStateSynchronousResponseOnAShaft",
    "ConceptGearSteadyStateSynchronousResponseOnAShaft",
    "ConicalGearMeshSteadyStateSynchronousResponseOnAShaft",
    "ConicalGearSetSteadyStateSynchronousResponseOnAShaft",
    "ConicalGearSteadyStateSynchronousResponseOnAShaft",
    "ConnectionSteadyStateSynchronousResponseOnAShaft",
    "ConnectorSteadyStateSynchronousResponseOnAShaft",
    "CouplingConnectionSteadyStateSynchronousResponseOnAShaft",
    "CouplingHalfSteadyStateSynchronousResponseOnAShaft",
    "CouplingSteadyStateSynchronousResponseOnAShaft",
    "CVTBeltConnectionSteadyStateSynchronousResponseOnAShaft",
    "CVTPulleySteadyStateSynchronousResponseOnAShaft",
    "CVTSteadyStateSynchronousResponseOnAShaft",
    "CycloidalAssemblySteadyStateSynchronousResponseOnAShaft",
    "CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseOnAShaft",
    "CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseOnAShaft",
    "CycloidalDiscSteadyStateSynchronousResponseOnAShaft",
    "CylindricalGearMeshSteadyStateSynchronousResponseOnAShaft",
    "CylindricalGearSetSteadyStateSynchronousResponseOnAShaft",
    "CylindricalGearSteadyStateSynchronousResponseOnAShaft",
    "CylindricalPlanetGearSteadyStateSynchronousResponseOnAShaft",
    "DatumSteadyStateSynchronousResponseOnAShaft",
    "ExternalCADModelSteadyStateSynchronousResponseOnAShaft",
    "FaceGearMeshSteadyStateSynchronousResponseOnAShaft",
    "FaceGearSetSteadyStateSynchronousResponseOnAShaft",
    "FaceGearSteadyStateSynchronousResponseOnAShaft",
    "FEPartSteadyStateSynchronousResponseOnAShaft",
    "FlexiblePinAssemblySteadyStateSynchronousResponseOnAShaft",
    "GearMeshSteadyStateSynchronousResponseOnAShaft",
    "GearSetSteadyStateSynchronousResponseOnAShaft",
    "GearSteadyStateSynchronousResponseOnAShaft",
    "GuideDxfModelSteadyStateSynchronousResponseOnAShaft",
    "HypoidGearMeshSteadyStateSynchronousResponseOnAShaft",
    "HypoidGearSetSteadyStateSynchronousResponseOnAShaft",
    "HypoidGearSteadyStateSynchronousResponseOnAShaft",
    "InterMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft",
    "KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseOnAShaft",
    "MassDiscSteadyStateSynchronousResponseOnAShaft",
    "MeasurementComponentSteadyStateSynchronousResponseOnAShaft",
    "MountableComponentSteadyStateSynchronousResponseOnAShaft",
    "OilSealSteadyStateSynchronousResponseOnAShaft",
    "PartSteadyStateSynchronousResponseOnAShaft",
    "PartToPartShearCouplingConnectionSteadyStateSynchronousResponseOnAShaft",
    "PartToPartShearCouplingHalfSteadyStateSynchronousResponseOnAShaft",
    "PartToPartShearCouplingSteadyStateSynchronousResponseOnAShaft",
    "PlanetaryConnectionSteadyStateSynchronousResponseOnAShaft",
    "PlanetaryGearSetSteadyStateSynchronousResponseOnAShaft",
    "PlanetCarrierSteadyStateSynchronousResponseOnAShaft",
    "PointLoadSteadyStateSynchronousResponseOnAShaft",
    "PowerLoadSteadyStateSynchronousResponseOnAShaft",
    "PulleySteadyStateSynchronousResponseOnAShaft",
    "RingPinsSteadyStateSynchronousResponseOnAShaft",
    "RingPinsToDiscConnectionSteadyStateSynchronousResponseOnAShaft",
    "RollingRingAssemblySteadyStateSynchronousResponseOnAShaft",
    "RollingRingConnectionSteadyStateSynchronousResponseOnAShaft",
    "RollingRingSteadyStateSynchronousResponseOnAShaft",
    "RootAssemblySteadyStateSynchronousResponseOnAShaft",
    "ShaftHubConnectionSteadyStateSynchronousResponseOnAShaft",
    "ShaftSteadyStateSynchronousResponseOnAShaft",
    "ShaftToMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft",
    "SpecialisedAssemblySteadyStateSynchronousResponseOnAShaft",
    "SpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft",
    "SpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft",
    "SpiralBevelGearSteadyStateSynchronousResponseOnAShaft",
    "SpringDamperConnectionSteadyStateSynchronousResponseOnAShaft",
    "SpringDamperHalfSteadyStateSynchronousResponseOnAShaft",
    "SpringDamperSteadyStateSynchronousResponseOnAShaft",
    "SteadyStateSynchronousResponseOnAShaft",
    "StraightBevelDiffGearMeshSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelDiffGearSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelGearMeshSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelGearSetSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelGearSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelPlanetGearSteadyStateSynchronousResponseOnAShaft",
    "StraightBevelSunGearSteadyStateSynchronousResponseOnAShaft",
    "SynchroniserHalfSteadyStateSynchronousResponseOnAShaft",
    "SynchroniserPartSteadyStateSynchronousResponseOnAShaft",
    "SynchroniserSleeveSteadyStateSynchronousResponseOnAShaft",
    "SynchroniserSteadyStateSynchronousResponseOnAShaft",
    "TorqueConverterConnectionSteadyStateSynchronousResponseOnAShaft",
    "TorqueConverterPumpSteadyStateSynchronousResponseOnAShaft",
    "TorqueConverterSteadyStateSynchronousResponseOnAShaft",
    "TorqueConverterTurbineSteadyStateSynchronousResponseOnAShaft",
    "UnbalancedMassSteadyStateSynchronousResponseOnAShaft",
    "VirtualComponentSteadyStateSynchronousResponseOnAShaft",
    "WormGearMeshSteadyStateSynchronousResponseOnAShaft",
    "WormGearSetSteadyStateSynchronousResponseOnAShaft",
    "WormGearSteadyStateSynchronousResponseOnAShaft",
    "ZerolBevelGearMeshSteadyStateSynchronousResponseOnAShaft",
    "ZerolBevelGearSetSteadyStateSynchronousResponseOnAShaft",
    "ZerolBevelGearSteadyStateSynchronousResponseOnAShaft",
)



"""DynamicAnalysis"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy.system_model.analyses_and_results.analysis_cases import _7544
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_DYNAMIC_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.DynamicAnalyses", "DynamicAnalysis"
)

if TYPE_CHECKING:
    from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses import (
        _3035,
    )
    from mastapy.system_model.analyses_and_results.stability_analyses import _3816
    from mastapy.system_model.analyses_and_results.modal_analyses import _4625
    from mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
        _4909,
    )
    from mastapy.system_model.analyses_and_results.harmonic_analyses import _5732
    from mastapy.system_model.analyses_and_results.analysis_cases import _7550, _7535
    from mastapy.system_model.analyses_and_results import _2650


__docformat__ = "restructuredtext en"
__all__ = ("DynamicAnalysis",)


Self = TypeVar("Self", bound="DynamicAnalysis")


class DynamicAnalysis(_7544.FEAnalysis):
    """DynamicAnalysis

    This is a mastapy class.
    """

    TYPE = _DYNAMIC_ANALYSIS
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_DynamicAnalysis")

    class _Cast_DynamicAnalysis:
        """Special nested class for casting DynamicAnalysis to subclasses."""

        def __init__(
            self: "DynamicAnalysis._Cast_DynamicAnalysis", parent: "DynamicAnalysis"
        ):
            self._parent = parent

        @property
        def fe_analysis(
            self: "DynamicAnalysis._Cast_DynamicAnalysis",
        ) -> "_7544.FEAnalysis":
            return self._parent._cast(_7544.FEAnalysis)

        @property
        def static_load_analysis_case(
            self: "DynamicAnalysis._Cast_DynamicAnalysis",
        ) -> "_7550.StaticLoadAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7550

            return self._parent._cast(_7550.StaticLoadAnalysisCase)

        @property
        def analysis_case(
            self: "DynamicAnalysis._Cast_DynamicAnalysis",
        ) -> "_7535.AnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7535

            return self._parent._cast(_7535.AnalysisCase)

        @property
        def context(self: "DynamicAnalysis._Cast_DynamicAnalysis") -> "_2650.Context":
            from mastapy.system_model.analyses_and_results import _2650

            return self._parent._cast(_2650.Context)

        @property
        def dynamic_model_for_steady_state_synchronous_response(
            self: "DynamicAnalysis._Cast_DynamicAnalysis",
        ) -> "_3035.DynamicModelForSteadyStateSynchronousResponse":
            from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses import (
                _3035,
            )

            return self._parent._cast(
                _3035.DynamicModelForSteadyStateSynchronousResponse
            )

        @property
        def dynamic_model_for_stability_analysis(
            self: "DynamicAnalysis._Cast_DynamicAnalysis",
        ) -> "_3816.DynamicModelForStabilityAnalysis":
            from mastapy.system_model.analyses_and_results.stability_analyses import (
                _3816,
            )

            return self._parent._cast(_3816.DynamicModelForStabilityAnalysis)

        @property
        def dynamic_model_for_modal_analysis(
            self: "DynamicAnalysis._Cast_DynamicAnalysis",
        ) -> "_4625.DynamicModelForModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses import _4625

            return self._parent._cast(_4625.DynamicModelForModalAnalysis)

        @property
        def dynamic_model_at_a_stiffness(
            self: "DynamicAnalysis._Cast_DynamicAnalysis",
        ) -> "_4909.DynamicModelAtAStiffness":
            from mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
                _4909,
            )

            return self._parent._cast(_4909.DynamicModelAtAStiffness)

        @property
        def dynamic_model_for_harmonic_analysis(
            self: "DynamicAnalysis._Cast_DynamicAnalysis",
        ) -> "_5732.DynamicModelForHarmonicAnalysis":
            from mastapy.system_model.analyses_and_results.harmonic_analyses import (
                _5732,
            )

            return self._parent._cast(_5732.DynamicModelForHarmonicAnalysis)

        @property
        def dynamic_analysis(
            self: "DynamicAnalysis._Cast_DynamicAnalysis",
        ) -> "DynamicAnalysis":
            return self._parent

        def __getattr__(self: "DynamicAnalysis._Cast_DynamicAnalysis", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "DynamicAnalysis.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def cast_to(self: Self) -> "DynamicAnalysis._Cast_DynamicAnalysis":
        return self._Cast_DynamicAnalysis(self)



"""ProfileReliefWithDeviation"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal import constructor
from mastapy.gears.gear_designs.cylindrical.micro_geometry import _1128
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_PROFILE_RELIEF_WITH_DEVIATION = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Cylindrical.MicroGeometry",
    "ProfileReliefWithDeviation",
)

if TYPE_CHECKING:
    from mastapy.gears.gear_designs.cylindrical import _1025
    from mastapy.gears.gear_designs.cylindrical.micro_geometry import (
        _1125,
        _1127,
        _1131,
    )


__docformat__ = "restructuredtext en"
__all__ = ("ProfileReliefWithDeviation",)


Self = TypeVar("Self", bound="ProfileReliefWithDeviation")


class ProfileReliefWithDeviation(_1128.ReliefWithDeviation):
    """ProfileReliefWithDeviation

    This is a mastapy class.
    """

    TYPE = _PROFILE_RELIEF_WITH_DEVIATION
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_ProfileReliefWithDeviation")

    class _Cast_ProfileReliefWithDeviation:
        """Special nested class for casting ProfileReliefWithDeviation to subclasses."""

        def __init__(
            self: "ProfileReliefWithDeviation._Cast_ProfileReliefWithDeviation",
            parent: "ProfileReliefWithDeviation",
        ):
            self._parent = parent

        @property
        def relief_with_deviation(
            self: "ProfileReliefWithDeviation._Cast_ProfileReliefWithDeviation",
        ) -> "_1128.ReliefWithDeviation":
            return self._parent._cast(_1128.ReliefWithDeviation)

        @property
        def profile_form_relief_with_deviation(
            self: "ProfileReliefWithDeviation._Cast_ProfileReliefWithDeviation",
        ) -> "_1125.ProfileFormReliefWithDeviation":
            from mastapy.gears.gear_designs.cylindrical.micro_geometry import _1125

            return self._parent._cast(_1125.ProfileFormReliefWithDeviation)

        @property
        def profile_slope_relief_with_deviation(
            self: "ProfileReliefWithDeviation._Cast_ProfileReliefWithDeviation",
        ) -> "_1127.ProfileSlopeReliefWithDeviation":
            from mastapy.gears.gear_designs.cylindrical.micro_geometry import _1127

            return self._parent._cast(_1127.ProfileSlopeReliefWithDeviation)

        @property
        def total_profile_relief_with_deviation(
            self: "ProfileReliefWithDeviation._Cast_ProfileReliefWithDeviation",
        ) -> "_1131.TotalProfileReliefWithDeviation":
            from mastapy.gears.gear_designs.cylindrical.micro_geometry import _1131

            return self._parent._cast(_1131.TotalProfileReliefWithDeviation)

        @property
        def profile_relief_with_deviation(
            self: "ProfileReliefWithDeviation._Cast_ProfileReliefWithDeviation",
        ) -> "ProfileReliefWithDeviation":
            return self._parent

        def __getattr__(
            self: "ProfileReliefWithDeviation._Cast_ProfileReliefWithDeviation",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "ProfileReliefWithDeviation.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def profile_relief(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ProfileRelief

        if temp is None:
            return 0.0

        return temp

    @property
    def roll_distance(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RollDistance

        if temp is None:
            return 0.0

        return temp

    @property
    def position_on_profile(self: Self) -> "_1025.CylindricalGearProfileMeasurement":
        """mastapy.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PositionOnProfile

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "ProfileReliefWithDeviation._Cast_ProfileReliefWithDeviation":
        return self._Cast_ProfileReliefWithDeviation(self)



"""MicroGeometryDesignSpaceSearch"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor, conversion
from mastapy._internal.implicit import list_with_selected_item
from mastapy.gears.ltca.cylindrical import _856, _857, _860
from mastapy.gears.gear_set_pareto_optimiser import _906
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_MICRO_GEOMETRY_DESIGN_SPACE_SEARCH = python_net_import(
    "SMT.MastaAPI.Gears.GearSetParetoOptimiser", "MicroGeometryDesignSpaceSearch"
)

if TYPE_CHECKING:
    from mastapy.gears.gear_set_pareto_optimiser import _919
    from mastapy.gears.gear_designs.cylindrical.micro_geometry import _1107


__docformat__ = "restructuredtext en"
__all__ = ("MicroGeometryDesignSpaceSearch",)


Self = TypeVar("Self", bound="MicroGeometryDesignSpaceSearch")


class MicroGeometryDesignSpaceSearch(
    _906.DesignSpaceSearchBase[
        "_860.CylindricalGearSetLoadDistributionAnalysis",
        "_917.MicroGeometryDesignSpaceSearchCandidate",
    ]
):
    """MicroGeometryDesignSpaceSearch

    This is a mastapy class.
    """

    TYPE = _MICRO_GEOMETRY_DESIGN_SPACE_SEARCH
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_MicroGeometryDesignSpaceSearch")

    class _Cast_MicroGeometryDesignSpaceSearch:
        """Special nested class for casting MicroGeometryDesignSpaceSearch to subclasses."""

        def __init__(
            self: "MicroGeometryDesignSpaceSearch._Cast_MicroGeometryDesignSpaceSearch",
            parent: "MicroGeometryDesignSpaceSearch",
        ):
            self._parent = parent

        @property
        def design_space_search_base(
            self: "MicroGeometryDesignSpaceSearch._Cast_MicroGeometryDesignSpaceSearch",
        ) -> "_906.DesignSpaceSearchBase":
            return self._parent._cast(_906.DesignSpaceSearchBase)

        @property
        def micro_geometry_gear_set_design_space_search(
            self: "MicroGeometryDesignSpaceSearch._Cast_MicroGeometryDesignSpaceSearch",
        ) -> "_919.MicroGeometryGearSetDesignSpaceSearch":
            from mastapy.gears.gear_set_pareto_optimiser import _919

            return self._parent._cast(_919.MicroGeometryGearSetDesignSpaceSearch)

        @property
        def micro_geometry_design_space_search(
            self: "MicroGeometryDesignSpaceSearch._Cast_MicroGeometryDesignSpaceSearch",
        ) -> "MicroGeometryDesignSpaceSearch":
            return self._parent

        def __getattr__(
            self: "MicroGeometryDesignSpaceSearch._Cast_MicroGeometryDesignSpaceSearch",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "MicroGeometryDesignSpaceSearch.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def name(self: Self) -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Name

        if temp is None:
            return ""

        return temp

    @property
    def run_all_planetary_meshes(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.RunAllPlanetaryMeshes

        if temp is None:
            return False

        return temp

    @run_all_planetary_meshes.setter
    @enforce_parameter_types
    def run_all_planetary_meshes(self: Self, value: "bool"):
        self.wrapped.RunAllPlanetaryMeshes = bool(value) if value is not None else False

    @property
    def select_gear(
        self: Self,
    ) -> "list_with_selected_item.ListWithSelectedItem_CylindricalGearLoadDistributionAnalysis":
        """ListWithSelectedItem[mastapy.gears.ltca.cylindrical.CylindricalGearLoadDistributionAnalysis]"""
        temp = self.wrapped.SelectGear

        if temp is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_CylindricalGearLoadDistributionAnalysis",
        )(temp)

    @select_gear.setter
    @enforce_parameter_types
    def select_gear(self: Self, value: "_856.CylindricalGearLoadDistributionAnalysis"):
        wrapper_type = (
            list_with_selected_item.ListWithSelectedItem_CylindricalGearLoadDistributionAnalysis.wrapper_type()
        )
        enclosed_type = (
            list_with_selected_item.ListWithSelectedItem_CylindricalGearLoadDistributionAnalysis.implicit_type()
        )
        value = wrapper_type[enclosed_type](
            value.wrapped if value is not None else None
        )
        self.wrapped.SelectGear = value

    @property
    def select_mesh(
        self: Self,
    ) -> "list_with_selected_item.ListWithSelectedItem_CylindricalGearMeshLoadDistributionAnalysis":
        """ListWithSelectedItem[mastapy.gears.ltca.cylindrical.CylindricalGearMeshLoadDistributionAnalysis]"""
        temp = self.wrapped.SelectMesh

        if temp is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_CylindricalGearMeshLoadDistributionAnalysis",
        )(temp)

    @select_mesh.setter
    @enforce_parameter_types
    def select_mesh(
        self: Self, value: "_857.CylindricalGearMeshLoadDistributionAnalysis"
    ):
        wrapper_type = (
            list_with_selected_item.ListWithSelectedItem_CylindricalGearMeshLoadDistributionAnalysis.wrapper_type()
        )
        enclosed_type = (
            list_with_selected_item.ListWithSelectedItem_CylindricalGearMeshLoadDistributionAnalysis.implicit_type()
        )
        value = wrapper_type[enclosed_type](
            value.wrapped if value is not None else None
        )
        self.wrapped.SelectMesh = value

    @property
    def load_case_duty_cycle(
        self: Self,
    ) -> "_860.CylindricalGearSetLoadDistributionAnalysis":
        """mastapy.gears.ltca.cylindrical.CylindricalGearSetLoadDistributionAnalysis

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LoadCaseDutyCycle

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def selected_candidate_micro_geometry(
        self: Self,
    ) -> "_1107.CylindricalGearSetMicroGeometry":
        """mastapy.gears.gear_designs.cylindrical.micro_geometry.CylindricalGearSetMicroGeometry

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SelectedCandidateMicroGeometry

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def all_candidate_gear_sets(
        self: Self,
    ) -> "List[_1107.CylindricalGearSetMicroGeometry]":
        """List[mastapy.gears.gear_designs.cylindrical.micro_geometry.CylindricalGearSetMicroGeometry]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AllCandidateGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def candidate_gear_sets(
        self: Self,
    ) -> "List[_1107.CylindricalGearSetMicroGeometry]":
        """List[mastapy.gears.gear_designs.cylindrical.micro_geometry.CylindricalGearSetMicroGeometry]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CandidateGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    def add_chart(self: Self):
        """Method does not return."""
        self.wrapped.AddChart()

    def reset_charts(self: Self):
        """Method does not return."""
        self.wrapped.ResetCharts()

    @property
    def cast_to(
        self: Self,
    ) -> "MicroGeometryDesignSpaceSearch._Cast_MicroGeometryDesignSpaceSearch":
        return self._Cast_MicroGeometryDesignSpaceSearch(self)



"""HobManufactureError"""
from __future__ import annotations

from typing import TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy.gears.manufacturing.cylindrical.hobbing_process_simulation_new import _689
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_HOB_MANUFACTURE_ERROR = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.HobbingProcessSimulationNew",
    "HobManufactureError",
)


__docformat__ = "restructuredtext en"
__all__ = ("HobManufactureError",)


Self = TypeVar("Self", bound="HobManufactureError")


class HobManufactureError(_689.RackManufactureError):
    """HobManufactureError

    This is a mastapy class.
    """

    TYPE = _HOB_MANUFACTURE_ERROR
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_HobManufactureError")

    class _Cast_HobManufactureError:
        """Special nested class for casting HobManufactureError to subclasses."""

        def __init__(
            self: "HobManufactureError._Cast_HobManufactureError",
            parent: "HobManufactureError",
        ):
            self._parent = parent

        @property
        def rack_manufacture_error(
            self: "HobManufactureError._Cast_HobManufactureError",
        ) -> "_689.RackManufactureError":
            return self._parent._cast(_689.RackManufactureError)

        @property
        def hob_manufacture_error(
            self: "HobManufactureError._Cast_HobManufactureError",
        ) -> "HobManufactureError":
            return self._parent

        def __getattr__(
            self: "HobManufactureError._Cast_HobManufactureError", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "HobManufactureError.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def total_relief_variation(self: Self) -> "float":
        """float"""
        temp = self.wrapped.TotalReliefVariation

        if temp is None:
            return 0.0

        return temp

    @total_relief_variation.setter
    @enforce_parameter_types
    def total_relief_variation(self: Self, value: "float"):
        self.wrapped.TotalReliefVariation = float(value) if value is not None else 0.0

    @property
    def use_sin_curve_for_top_relief(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.UseSinCurveForTopRelief

        if temp is None:
            return False

        return temp

    @use_sin_curve_for_top_relief.setter
    @enforce_parameter_types
    def use_sin_curve_for_top_relief(self: Self, value: "bool"):
        self.wrapped.UseSinCurveForTopRelief = (
            bool(value) if value is not None else False
        )

    @property
    def cast_to(self: Self) -> "HobManufactureError._Cast_HobManufactureError":
        return self._Cast_HobManufactureError(self)



"""LobattoIIICTransientSolver"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy.nodal_analysis.system_solvers import _116
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_LOBATTO_IIIC_TRANSIENT_SOLVER = python_net_import(
    "SMT.MastaAPI.NodalAnalysis.SystemSolvers", "LobattoIIICTransientSolver"
)

if TYPE_CHECKING:
    from mastapy.nodal_analysis.system_solvers import _104, _118, _103, _117, _115


__docformat__ = "restructuredtext en"
__all__ = ("LobattoIIICTransientSolver",)


Self = TypeVar("Self", bound="LobattoIIICTransientSolver")


class LobattoIIICTransientSolver(_116.StepHalvingTransientSolver):
    """LobattoIIICTransientSolver

    This is a mastapy class.
    """

    TYPE = _LOBATTO_IIIC_TRANSIENT_SOLVER
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_LobattoIIICTransientSolver")

    class _Cast_LobattoIIICTransientSolver:
        """Special nested class for casting LobattoIIICTransientSolver to subclasses."""

        def __init__(
            self: "LobattoIIICTransientSolver._Cast_LobattoIIICTransientSolver",
            parent: "LobattoIIICTransientSolver",
        ):
            self._parent = parent

        @property
        def step_halving_transient_solver(
            self: "LobattoIIICTransientSolver._Cast_LobattoIIICTransientSolver",
        ) -> "_116.StepHalvingTransientSolver":
            return self._parent._cast(_116.StepHalvingTransientSolver)

        @property
        def internal_transient_solver(
            self: "LobattoIIICTransientSolver._Cast_LobattoIIICTransientSolver",
        ) -> "_104.InternalTransientSolver":
            from mastapy.nodal_analysis.system_solvers import _104

            return self._parent._cast(_104.InternalTransientSolver)

        @property
        def transient_solver(
            self: "LobattoIIICTransientSolver._Cast_LobattoIIICTransientSolver",
        ) -> "_118.TransientSolver":
            from mastapy.nodal_analysis.system_solvers import _118

            return self._parent._cast(_118.TransientSolver)

        @property
        def dynamic_solver(
            self: "LobattoIIICTransientSolver._Cast_LobattoIIICTransientSolver",
        ) -> "_103.DynamicSolver":
            from mastapy.nodal_analysis.system_solvers import _103

            return self._parent._cast(_103.DynamicSolver)

        @property
        def stiffness_solver(
            self: "LobattoIIICTransientSolver._Cast_LobattoIIICTransientSolver",
        ) -> "_117.StiffnessSolver":
            from mastapy.nodal_analysis.system_solvers import _117

            return self._parent._cast(_117.StiffnessSolver)

        @property
        def solver(
            self: "LobattoIIICTransientSolver._Cast_LobattoIIICTransientSolver",
        ) -> "_115.Solver":
            from mastapy.nodal_analysis.system_solvers import _115

            return self._parent._cast(_115.Solver)

        @property
        def lobatto_iiic_transient_solver(
            self: "LobattoIIICTransientSolver._Cast_LobattoIIICTransientSolver",
        ) -> "LobattoIIICTransientSolver":
            return self._parent

        def __getattr__(
            self: "LobattoIIICTransientSolver._Cast_LobattoIIICTransientSolver",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "LobattoIIICTransientSolver.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def cast_to(
        self: Self,
    ) -> "LobattoIIICTransientSolver._Cast_LobattoIIICTransientSolver":
        return self._Cast_LobattoIIICTransientSolver(self)



"""CylindricalGearFormGrindingWheel"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import constructor
from mastapy.gears.manufacturing.cylindrical.cutters import _713
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_FORM_GRINDING_WHEEL = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.Cutters",
    "CylindricalGearFormGrindingWheel",
)

if TYPE_CHECKING:
    from mastapy.math_utility import _1534
    from mastapy.gears.manufacturing.cylindrical.cutters import _706
    from mastapy.utility.databases import _1829


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalGearFormGrindingWheel",)


Self = TypeVar("Self", bound="CylindricalGearFormGrindingWheel")


class CylindricalGearFormGrindingWheel(_713.CylindricalGearRealCutterDesign):
    """CylindricalGearFormGrindingWheel

    This is a mastapy class.
    """

    TYPE = _CYLINDRICAL_GEAR_FORM_GRINDING_WHEEL
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_CylindricalGearFormGrindingWheel")

    class _Cast_CylindricalGearFormGrindingWheel:
        """Special nested class for casting CylindricalGearFormGrindingWheel to subclasses."""

        def __init__(
            self: "CylindricalGearFormGrindingWheel._Cast_CylindricalGearFormGrindingWheel",
            parent: "CylindricalGearFormGrindingWheel",
        ):
            self._parent = parent

        @property
        def cylindrical_gear_real_cutter_design(
            self: "CylindricalGearFormGrindingWheel._Cast_CylindricalGearFormGrindingWheel",
        ) -> "_713.CylindricalGearRealCutterDesign":
            return self._parent._cast(_713.CylindricalGearRealCutterDesign)

        @property
        def cylindrical_gear_abstract_cutter_design(
            self: "CylindricalGearFormGrindingWheel._Cast_CylindricalGearFormGrindingWheel",
        ) -> "_706.CylindricalGearAbstractCutterDesign":
            from mastapy.gears.manufacturing.cylindrical.cutters import _706

            return self._parent._cast(_706.CylindricalGearAbstractCutterDesign)

        @property
        def named_database_item(
            self: "CylindricalGearFormGrindingWheel._Cast_CylindricalGearFormGrindingWheel",
        ) -> "_1829.NamedDatabaseItem":
            from mastapy.utility.databases import _1829

            return self._parent._cast(_1829.NamedDatabaseItem)

        @property
        def cylindrical_gear_form_grinding_wheel(
            self: "CylindricalGearFormGrindingWheel._Cast_CylindricalGearFormGrindingWheel",
        ) -> "CylindricalGearFormGrindingWheel":
            return self._parent

        def __getattr__(
            self: "CylindricalGearFormGrindingWheel._Cast_CylindricalGearFormGrindingWheel",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "CylindricalGearFormGrindingWheel.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def has_tolerances(self: Self) -> "bool":
        """bool"""
        temp = self.wrapped.HasTolerances

        if temp is None:
            return False

        return temp

    @has_tolerances.setter
    @enforce_parameter_types
    def has_tolerances(self: Self, value: "bool"):
        self.wrapped.HasTolerances = bool(value) if value is not None else False

    @property
    def radius(self: Self) -> "float":
        """float"""
        temp = self.wrapped.Radius

        if temp is None:
            return 0.0

        return temp

    @radius.setter
    @enforce_parameter_types
    def radius(self: Self, value: "float"):
        self.wrapped.Radius = float(value) if value is not None else 0.0

    @property
    def right_hand_cutting_edge_shape(self: Self) -> "_1534.Vector2DListAccessor":
        """mastapy.math_utility.Vector2DListAccessor"""
        temp = self.wrapped.RightHandCuttingEdgeShape

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @right_hand_cutting_edge_shape.setter
    @enforce_parameter_types
    def right_hand_cutting_edge_shape(self: Self, value: "_1534.Vector2DListAccessor"):
        self.wrapped.RightHandCuttingEdgeShape = value.wrapped

    @property
    def cast_to(
        self: Self,
    ) -> "CylindricalGearFormGrindingWheel._Cast_CylindricalGearFormGrindingWheel":
        return self._Cast_CylindricalGearFormGrindingWheel(self)



"""GearMeshLoadedContactLine"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal import conversion
from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_GEAR_MESH_LOADED_CONTACT_LINE = python_net_import(
    "SMT.MastaAPI.Gears.LTCA", "GearMeshLoadedContactLine"
)

if TYPE_CHECKING:
    from mastapy.gears.ltca import _844
    from mastapy.gears.ltca.cylindrical import _858
    from mastapy.gears.ltca.conical import _872


__docformat__ = "restructuredtext en"
__all__ = ("GearMeshLoadedContactLine",)


Self = TypeVar("Self", bound="GearMeshLoadedContactLine")


class GearMeshLoadedContactLine(_0.APIBase):
    """GearMeshLoadedContactLine

    This is a mastapy class.
    """

    TYPE = _GEAR_MESH_LOADED_CONTACT_LINE
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_GearMeshLoadedContactLine")

    class _Cast_GearMeshLoadedContactLine:
        """Special nested class for casting GearMeshLoadedContactLine to subclasses."""

        def __init__(
            self: "GearMeshLoadedContactLine._Cast_GearMeshLoadedContactLine",
            parent: "GearMeshLoadedContactLine",
        ):
            self._parent = parent

        @property
        def cylindrical_gear_mesh_loaded_contact_line(
            self: "GearMeshLoadedContactLine._Cast_GearMeshLoadedContactLine",
        ) -> "_858.CylindricalGearMeshLoadedContactLine":
            from mastapy.gears.ltca.cylindrical import _858

            return self._parent._cast(_858.CylindricalGearMeshLoadedContactLine)

        @property
        def conical_mesh_loaded_contact_line(
            self: "GearMeshLoadedContactLine._Cast_GearMeshLoadedContactLine",
        ) -> "_872.ConicalMeshLoadedContactLine":
            from mastapy.gears.ltca.conical import _872

            return self._parent._cast(_872.ConicalMeshLoadedContactLine)

        @property
        def gear_mesh_loaded_contact_line(
            self: "GearMeshLoadedContactLine._Cast_GearMeshLoadedContactLine",
        ) -> "GearMeshLoadedContactLine":
            return self._parent

        def __getattr__(
            self: "GearMeshLoadedContactLine._Cast_GearMeshLoadedContactLine", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "GearMeshLoadedContactLine.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def contact_line_index(self: Self) -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactLineIndex

        if temp is None:
            return 0

        return temp

    @property
    def mesh_position_index(self: Self) -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeshPositionIndex

        if temp is None:
            return 0

        return temp

    @property
    def tooth_number_of_gear_a(self: Self) -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ToothNumberOfGearA

        if temp is None:
            return 0

        return temp

    @property
    def tooth_number_of_gear_b(self: Self) -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ToothNumberOfGearB

        if temp is None:
            return 0

        return temp

    @property
    def loaded_contact_strip_end_points(
        self: Self,
    ) -> "List[_844.GearMeshLoadedContactPoint]":
        """List[mastapy.gears.ltca.GearMeshLoadedContactPoint]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LoadedContactStripEndPoints

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: Self,
    ) -> "GearMeshLoadedContactLine._Cast_GearMeshLoadedContactLine":
        return self._Cast_GearMeshLoadedContactLine(self)



"""BevelGearCompoundModalAnalysis"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, List

from mastapy._internal import conversion
from mastapy.system_model.analyses_and_results.modal_analyses.compound import _4732
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_BEVEL_GEAR_COMPOUND_MODAL_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses.Compound",
    "BevelGearCompoundModalAnalysis",
)

if TYPE_CHECKING:
    from mastapy.system_model.analyses_and_results.modal_analyses import _4589
    from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
        _4739,
        _4742,
        _4743,
        _4827,
        _4833,
        _4836,
        _4839,
        _4840,
        _4854,
        _4760,
        _4786,
        _4805,
        _4753,
        _4807,
    )
    from mastapy.system_model.analyses_and_results.analysis_cases import _7546, _7543
    from mastapy.system_model.analyses_and_results import _2651


__docformat__ = "restructuredtext en"
__all__ = ("BevelGearCompoundModalAnalysis",)


Self = TypeVar("Self", bound="BevelGearCompoundModalAnalysis")


class BevelGearCompoundModalAnalysis(_4732.AGMAGleasonConicalGearCompoundModalAnalysis):
    """BevelGearCompoundModalAnalysis

    This is a mastapy class.
    """

    TYPE = _BEVEL_GEAR_COMPOUND_MODAL_ANALYSIS
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_BevelGearCompoundModalAnalysis")

    class _Cast_BevelGearCompoundModalAnalysis:
        """Special nested class for casting BevelGearCompoundModalAnalysis to subclasses."""

        def __init__(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
            parent: "BevelGearCompoundModalAnalysis",
        ):
            self._parent = parent

        @property
        def agma_gleason_conical_gear_compound_modal_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_4732.AGMAGleasonConicalGearCompoundModalAnalysis":
            return self._parent._cast(_4732.AGMAGleasonConicalGearCompoundModalAnalysis)

        @property
        def conical_gear_compound_modal_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_4760.ConicalGearCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4760,
            )

            return self._parent._cast(_4760.ConicalGearCompoundModalAnalysis)

        @property
        def gear_compound_modal_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_4786.GearCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4786,
            )

            return self._parent._cast(_4786.GearCompoundModalAnalysis)

        @property
        def mountable_component_compound_modal_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_4805.MountableComponentCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4805,
            )

            return self._parent._cast(_4805.MountableComponentCompoundModalAnalysis)

        @property
        def component_compound_modal_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_4753.ComponentCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4753,
            )

            return self._parent._cast(_4753.ComponentCompoundModalAnalysis)

        @property
        def part_compound_modal_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_4807.PartCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4807,
            )

            return self._parent._cast(_4807.PartCompoundModalAnalysis)

        @property
        def part_compound_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_7546.PartCompoundAnalysis":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7546

            return self._parent._cast(_7546.PartCompoundAnalysis)

        @property
        def design_entity_compound_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_7543.DesignEntityCompoundAnalysis":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7543

            return self._parent._cast(_7543.DesignEntityCompoundAnalysis)

        @property
        def design_entity_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def bevel_differential_gear_compound_modal_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_4739.BevelDifferentialGearCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4739,
            )

            return self._parent._cast(_4739.BevelDifferentialGearCompoundModalAnalysis)

        @property
        def bevel_differential_planet_gear_compound_modal_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_4742.BevelDifferentialPlanetGearCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4742,
            )

            return self._parent._cast(
                _4742.BevelDifferentialPlanetGearCompoundModalAnalysis
            )

        @property
        def bevel_differential_sun_gear_compound_modal_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_4743.BevelDifferentialSunGearCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4743,
            )

            return self._parent._cast(
                _4743.BevelDifferentialSunGearCompoundModalAnalysis
            )

        @property
        def spiral_bevel_gear_compound_modal_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_4827.SpiralBevelGearCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4827,
            )

            return self._parent._cast(_4827.SpiralBevelGearCompoundModalAnalysis)

        @property
        def straight_bevel_diff_gear_compound_modal_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_4833.StraightBevelDiffGearCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4833,
            )

            return self._parent._cast(_4833.StraightBevelDiffGearCompoundModalAnalysis)

        @property
        def straight_bevel_gear_compound_modal_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_4836.StraightBevelGearCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4836,
            )

            return self._parent._cast(_4836.StraightBevelGearCompoundModalAnalysis)

        @property
        def straight_bevel_planet_gear_compound_modal_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_4839.StraightBevelPlanetGearCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4839,
            )

            return self._parent._cast(
                _4839.StraightBevelPlanetGearCompoundModalAnalysis
            )

        @property
        def straight_bevel_sun_gear_compound_modal_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_4840.StraightBevelSunGearCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4840,
            )

            return self._parent._cast(_4840.StraightBevelSunGearCompoundModalAnalysis)

        @property
        def zerol_bevel_gear_compound_modal_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "_4854.ZerolBevelGearCompoundModalAnalysis":
            from mastapy.system_model.analyses_and_results.modal_analyses.compound import (
                _4854,
            )

            return self._parent._cast(_4854.ZerolBevelGearCompoundModalAnalysis)

        @property
        def bevel_gear_compound_modal_analysis(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
        ) -> "BevelGearCompoundModalAnalysis":
            return self._parent

        def __getattr__(
            self: "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "BevelGearCompoundModalAnalysis.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_analysis_cases(self: Self) -> "List[_4589.BevelGearModalAnalysis]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses.BevelGearModalAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentAnalysisCases

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def component_analysis_cases_ready(
        self: Self,
    ) -> "List[_4589.BevelGearModalAnalysis]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses.BevelGearModalAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentAnalysisCasesReady

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: Self,
    ) -> "BevelGearCompoundModalAnalysis._Cast_BevelGearCompoundModalAnalysis":
        return self._Cast_BevelGearCompoundModalAnalysis(self)



"""TorqueConverterConnectionModalAnalysisAtAStiffness"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
    _4894,
)
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_TORQUE_CONVERTER_CONNECTION_MODAL_ANALYSIS_AT_A_STIFFNESS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtAStiffness",
    "TorqueConverterConnectionModalAnalysisAtAStiffness",
)

if TYPE_CHECKING:
    from mastapy.system_model.connections_and_sockets.couplings import _2352
    from mastapy.system_model.analyses_and_results.static_loads import _6973
    from mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
        _4923,
        _4892,
    )
    from mastapy.system_model.analyses_and_results.analysis_cases import _7541, _7538
    from mastapy.system_model.analyses_and_results import _2649, _2653, _2651


__docformat__ = "restructuredtext en"
__all__ = ("TorqueConverterConnectionModalAnalysisAtAStiffness",)


Self = TypeVar("Self", bound="TorqueConverterConnectionModalAnalysisAtAStiffness")


class TorqueConverterConnectionModalAnalysisAtAStiffness(
    _4894.CouplingConnectionModalAnalysisAtAStiffness
):
    """TorqueConverterConnectionModalAnalysisAtAStiffness

    This is a mastapy class.
    """

    TYPE = _TORQUE_CONVERTER_CONNECTION_MODAL_ANALYSIS_AT_A_STIFFNESS
    _CastSelf = TypeVar(
        "_CastSelf", bound="_Cast_TorqueConverterConnectionModalAnalysisAtAStiffness"
    )

    class _Cast_TorqueConverterConnectionModalAnalysisAtAStiffness:
        """Special nested class for casting TorqueConverterConnectionModalAnalysisAtAStiffness to subclasses."""

        def __init__(
            self: "TorqueConverterConnectionModalAnalysisAtAStiffness._Cast_TorqueConverterConnectionModalAnalysisAtAStiffness",
            parent: "TorqueConverterConnectionModalAnalysisAtAStiffness",
        ):
            self._parent = parent

        @property
        def coupling_connection_modal_analysis_at_a_stiffness(
            self: "TorqueConverterConnectionModalAnalysisAtAStiffness._Cast_TorqueConverterConnectionModalAnalysisAtAStiffness",
        ) -> "_4894.CouplingConnectionModalAnalysisAtAStiffness":
            return self._parent._cast(_4894.CouplingConnectionModalAnalysisAtAStiffness)

        @property
        def inter_mountable_component_connection_modal_analysis_at_a_stiffness(
            self: "TorqueConverterConnectionModalAnalysisAtAStiffness._Cast_TorqueConverterConnectionModalAnalysisAtAStiffness",
        ) -> "_4923.InterMountableComponentConnectionModalAnalysisAtAStiffness":
            from mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
                _4923,
            )

            return self._parent._cast(
                _4923.InterMountableComponentConnectionModalAnalysisAtAStiffness
            )

        @property
        def connection_modal_analysis_at_a_stiffness(
            self: "TorqueConverterConnectionModalAnalysisAtAStiffness._Cast_TorqueConverterConnectionModalAnalysisAtAStiffness",
        ) -> "_4892.ConnectionModalAnalysisAtAStiffness":
            from mastapy.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
                _4892,
            )

            return self._parent._cast(_4892.ConnectionModalAnalysisAtAStiffness)

        @property
        def connection_static_load_analysis_case(
            self: "TorqueConverterConnectionModalAnalysisAtAStiffness._Cast_TorqueConverterConnectionModalAnalysisAtAStiffness",
        ) -> "_7541.ConnectionStaticLoadAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7541

            return self._parent._cast(_7541.ConnectionStaticLoadAnalysisCase)

        @property
        def connection_analysis_case(
            self: "TorqueConverterConnectionModalAnalysisAtAStiffness._Cast_TorqueConverterConnectionModalAnalysisAtAStiffness",
        ) -> "_7538.ConnectionAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7538

            return self._parent._cast(_7538.ConnectionAnalysisCase)

        @property
        def connection_analysis(
            self: "TorqueConverterConnectionModalAnalysisAtAStiffness._Cast_TorqueConverterConnectionModalAnalysisAtAStiffness",
        ) -> "_2649.ConnectionAnalysis":
            from mastapy.system_model.analyses_and_results import _2649

            return self._parent._cast(_2649.ConnectionAnalysis)

        @property
        def design_entity_single_context_analysis(
            self: "TorqueConverterConnectionModalAnalysisAtAStiffness._Cast_TorqueConverterConnectionModalAnalysisAtAStiffness",
        ) -> "_2653.DesignEntitySingleContextAnalysis":
            from mastapy.system_model.analyses_and_results import _2653

            return self._parent._cast(_2653.DesignEntitySingleContextAnalysis)

        @property
        def design_entity_analysis(
            self: "TorqueConverterConnectionModalAnalysisAtAStiffness._Cast_TorqueConverterConnectionModalAnalysisAtAStiffness",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def torque_converter_connection_modal_analysis_at_a_stiffness(
            self: "TorqueConverterConnectionModalAnalysisAtAStiffness._Cast_TorqueConverterConnectionModalAnalysisAtAStiffness",
        ) -> "TorqueConverterConnectionModalAnalysisAtAStiffness":
            return self._parent

        def __getattr__(
            self: "TorqueConverterConnectionModalAnalysisAtAStiffness._Cast_TorqueConverterConnectionModalAnalysisAtAStiffness",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self,
        instance_to_wrap: "TorqueConverterConnectionModalAnalysisAtAStiffness.TYPE",
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_design(self: Self) -> "_2352.TorqueConverterConnection":
        """mastapy.system_model.connections_and_sockets.couplings.TorqueConverterConnection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def connection_load_case(self: Self) -> "_6973.TorqueConverterConnectionLoadCase":
        """mastapy.system_model.analyses_and_results.static_loads.TorqueConverterConnectionLoadCase

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionLoadCase

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "TorqueConverterConnectionModalAnalysisAtAStiffness._Cast_TorqueConverterConnectionModalAnalysisAtAStiffness":
        return self._Cast_TorqueConverterConnectionModalAnalysisAtAStiffness(self)



"""KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.dynamic_analyses import _6346
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_KLINGELNBERG_CYCLO_PALLOID_SPIRAL_BEVEL_GEAR_MESH_DYNAMIC_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.DynamicAnalyses",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
)

if TYPE_CHECKING:
    from mastapy.system_model.connections_and_sockets.gears import _2320
    from mastapy.system_model.analyses_and_results.static_loads import _6920
    from mastapy.system_model.analyses_and_results.dynamic_analyses import (
        _6310,
        _6338,
        _6344,
        _6312,
    )
    from mastapy.system_model.analyses_and_results.analysis_cases import (
        _7540,
        _7541,
        _7538,
    )
    from mastapy.system_model.analyses_and_results import _2649, _2653, _2651


__docformat__ = "restructuredtext en"
__all__ = ("KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",)


Self = TypeVar(
    "Self", bound="KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis"
)


class KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis(
    _6346.KlingelnbergCycloPalloidConicalGearMeshDynamicAnalysis
):
    """KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis

    This is a mastapy class.
    """

    TYPE = _KLINGELNBERG_CYCLO_PALLOID_SPIRAL_BEVEL_GEAR_MESH_DYNAMIC_ANALYSIS
    _CastSelf = TypeVar(
        "_CastSelf",
        bound="_Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
    )

    class _Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis:
        """Special nested class for casting KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis to subclasses."""

        def __init__(
            self: "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis._Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
            parent: "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
        ):
            self._parent = parent

        @property
        def klingelnberg_cyclo_palloid_conical_gear_mesh_dynamic_analysis(
            self: "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis._Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
        ) -> "_6346.KlingelnbergCycloPalloidConicalGearMeshDynamicAnalysis":
            return self._parent._cast(
                _6346.KlingelnbergCycloPalloidConicalGearMeshDynamicAnalysis
            )

        @property
        def conical_gear_mesh_dynamic_analysis(
            self: "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis._Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
        ) -> "_6310.ConicalGearMeshDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses import _6310

            return self._parent._cast(_6310.ConicalGearMeshDynamicAnalysis)

        @property
        def gear_mesh_dynamic_analysis(
            self: "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis._Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
        ) -> "_6338.GearMeshDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses import _6338

            return self._parent._cast(_6338.GearMeshDynamicAnalysis)

        @property
        def inter_mountable_component_connection_dynamic_analysis(
            self: "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis._Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
        ) -> "_6344.InterMountableComponentConnectionDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses import _6344

            return self._parent._cast(
                _6344.InterMountableComponentConnectionDynamicAnalysis
            )

        @property
        def connection_dynamic_analysis(
            self: "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis._Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
        ) -> "_6312.ConnectionDynamicAnalysis":
            from mastapy.system_model.analyses_and_results.dynamic_analyses import _6312

            return self._parent._cast(_6312.ConnectionDynamicAnalysis)

        @property
        def connection_fe_analysis(
            self: "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis._Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
        ) -> "_7540.ConnectionFEAnalysis":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7540

            return self._parent._cast(_7540.ConnectionFEAnalysis)

        @property
        def connection_static_load_analysis_case(
            self: "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis._Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
        ) -> "_7541.ConnectionStaticLoadAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7541

            return self._parent._cast(_7541.ConnectionStaticLoadAnalysisCase)

        @property
        def connection_analysis_case(
            self: "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis._Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
        ) -> "_7538.ConnectionAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7538

            return self._parent._cast(_7538.ConnectionAnalysisCase)

        @property
        def connection_analysis(
            self: "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis._Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
        ) -> "_2649.ConnectionAnalysis":
            from mastapy.system_model.analyses_and_results import _2649

            return self._parent._cast(_2649.ConnectionAnalysis)

        @property
        def design_entity_single_context_analysis(
            self: "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis._Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
        ) -> "_2653.DesignEntitySingleContextAnalysis":
            from mastapy.system_model.analyses_and_results import _2653

            return self._parent._cast(_2653.DesignEntitySingleContextAnalysis)

        @property
        def design_entity_analysis(
            self: "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis._Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh_dynamic_analysis(
            self: "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis._Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
        ) -> "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis":
            return self._parent

        def __getattr__(
            self: "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis._Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(
        self: Self,
        instance_to_wrap: "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis.TYPE",
    ):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_design(
        self: Self,
    ) -> "_2320.KlingelnbergCycloPalloidSpiralBevelGearMesh":
        """mastapy.system_model.connections_and_sockets.gears.KlingelnbergCycloPalloidSpiralBevelGearMesh

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def connection_load_case(
        self: Self,
    ) -> "_6920.KlingelnbergCycloPalloidSpiralBevelGearMeshLoadCase":
        """mastapy.system_model.analyses_and_results.static_loads.KlingelnbergCycloPalloidSpiralBevelGearMeshLoadCase

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionLoadCase

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis._Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis":
        return self._Cast_KlingelnbergCycloPalloidSpiralBevelGearMeshDynamicAnalysis(
            self
        )



"""MutableCurve"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal import enum_with_selected_value_runtime, conversion
from mastapy._internal.implicit import enum_with_selected_value
from mastapy.geometry.two_d.curves import _313
from mastapy.gears.manufacturing.cylindrical.cutters import _719
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_MUTABLE_CURVE = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.Cutters", "MutableCurve"
)

if TYPE_CHECKING:
    from mastapy.gears.manufacturing.cylindrical.cutters import _703


__docformat__ = "restructuredtext en"
__all__ = ("MutableCurve",)


Self = TypeVar("Self", bound="MutableCurve")


class MutableCurve(_719.MutableCommon):
    """MutableCurve

    This is a mastapy class.
    """

    TYPE = _MUTABLE_CURVE
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_MutableCurve")

    class _Cast_MutableCurve:
        """Special nested class for casting MutableCurve to subclasses."""

        def __init__(self: "MutableCurve._Cast_MutableCurve", parent: "MutableCurve"):
            self._parent = parent

        @property
        def mutable_common(
            self: "MutableCurve._Cast_MutableCurve",
        ) -> "_719.MutableCommon":
            return self._parent._cast(_719.MutableCommon)

        @property
        def curve_in_linked_list(
            self: "MutableCurve._Cast_MutableCurve",
        ) -> "_703.CurveInLinkedList":
            from mastapy.gears.manufacturing.cylindrical.cutters import _703

            return self._parent._cast(_703.CurveInLinkedList)

        @property
        def mutable_curve(self: "MutableCurve._Cast_MutableCurve") -> "MutableCurve":
            return self._parent

        def __getattr__(self: "MutableCurve._Cast_MutableCurve", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "MutableCurve.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def crowning(self: Self) -> "float":
        """float"""
        temp = self.wrapped.Crowning

        if temp is None:
            return 0.0

        return temp

    @crowning.setter
    @enforce_parameter_types
    def crowning(self: Self, value: "float"):
        self.wrapped.Crowning = float(value) if value is not None else 0.0

    @property
    def curve_type(
        self: Self,
    ) -> "enum_with_selected_value.EnumWithSelectedValue_BasicCurveTypes":
        """EnumWithSelectedValue[mastapy.geometry.two_d.curves.BasicCurveTypes]"""
        temp = self.wrapped.CurveType

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_BasicCurveTypes.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @curve_type.setter
    @enforce_parameter_types
    def curve_type(self: Self, value: "_313.BasicCurveTypes"):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_BasicCurveTypes.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.CurveType = value

    @property
    def height(self: Self) -> "float":
        """float"""
        temp = self.wrapped.Height

        if temp is None:
            return 0.0

        return temp

    @height.setter
    @enforce_parameter_types
    def height(self: Self, value: "float"):
        self.wrapped.Height = float(value) if value is not None else 0.0

    @property
    def height_end(self: Self) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HeightEnd

        if temp is None:
            return 0.0

        return temp

    @property
    def length(self: Self) -> "float":
        """float"""
        temp = self.wrapped.Length

        if temp is None:
            return 0.0

        return temp

    @length.setter
    @enforce_parameter_types
    def length(self: Self, value: "float"):
        self.wrapped.Length = float(value) if value is not None else 0.0

    @property
    def linear_modification(self: Self) -> "float":
        """float"""
        temp = self.wrapped.LinearModification

        if temp is None:
            return 0.0

        return temp

    @linear_modification.setter
    @enforce_parameter_types
    def linear_modification(self: Self, value: "float"):
        self.wrapped.LinearModification = float(value) if value is not None else 0.0

    @property
    def nominal_section_pressure_angle(self: Self) -> "float":
        """float"""
        temp = self.wrapped.NominalSectionPressureAngle

        if temp is None:
            return 0.0

        return temp

    @nominal_section_pressure_angle.setter
    @enforce_parameter_types
    def nominal_section_pressure_angle(self: Self, value: "float"):
        self.wrapped.NominalSectionPressureAngle = (
            float(value) if value is not None else 0.0
        )

    @property
    def pressure_angle_modification(self: Self) -> "float":
        """float"""
        temp = self.wrapped.PressureAngleModification

        if temp is None:
            return 0.0

        return temp

    @pressure_angle_modification.setter
    @enforce_parameter_types
    def pressure_angle_modification(self: Self, value: "float"):
        self.wrapped.PressureAngleModification = (
            float(value) if value is not None else 0.0
        )

    @property
    def radius(self: Self) -> "float":
        """float"""
        temp = self.wrapped.Radius

        if temp is None:
            return 0.0

        return temp

    @radius.setter
    @enforce_parameter_types
    def radius(self: Self, value: "float"):
        self.wrapped.Radius = float(value) if value is not None else 0.0

    @property
    def cast_to(self: Self) -> "MutableCurve._Cast_MutableCurve":
        return self._Cast_MutableCurve(self)



"""BearingTypeExtraInformation"""
from __future__ import annotations

from typing import TypeVar, Any
from enum import Enum

from mastapy._internal.python_net import python_net_import

_BEARING_TYPE_EXTRA_INFORMATION = python_net_import(
    "SMT.MastaAPI.Bearings.BearingDesigns.Rolling", "BearingTypeExtraInformation"
)


__docformat__ = "restructuredtext en"
__all__ = ("BearingTypeExtraInformation",)


Self = TypeVar("Self", bound="BearingTypeExtraInformation")


class BearingTypeExtraInformation(Enum):
    """BearingTypeExtraInformation

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls):
        return _BEARING_TYPE_EXTRA_INFORMATION

    NONE = 0
    SKF_EXPLORER = 1
    XLIFE_PERFORMANCE = 2
    GENERATION_C = 4


def __enum_setattr(self: Self, attr: str, value: Any):
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: Self, attr: str):
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


BearingTypeExtraInformation.__setattr__ = __enum_setattr
BearingTypeExtraInformation.__delattr__ = __enum_delattr



"""HarmonicOrderForTE"""
from __future__ import annotations

from typing import TypeVar

from mastapy.utility.modal_analysis.gears import _1802
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_HARMONIC_ORDER_FOR_TE = python_net_import(
    "SMT.MastaAPI.Utility.ModalAnalysis.Gears", "HarmonicOrderForTE"
)


__docformat__ = "restructuredtext en"
__all__ = ("HarmonicOrderForTE",)


Self = TypeVar("Self", bound="HarmonicOrderForTE")


class HarmonicOrderForTE(_1802.OrderForTE):
    """HarmonicOrderForTE

    This is a mastapy class.
    """

    TYPE = _HARMONIC_ORDER_FOR_TE
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_HarmonicOrderForTE")

    class _Cast_HarmonicOrderForTE:
        """Special nested class for casting HarmonicOrderForTE to subclasses."""

        def __init__(
            self: "HarmonicOrderForTE._Cast_HarmonicOrderForTE",
            parent: "HarmonicOrderForTE",
        ):
            self._parent = parent

        @property
        def order_for_te(
            self: "HarmonicOrderForTE._Cast_HarmonicOrderForTE",
        ) -> "_1802.OrderForTE":
            return self._parent._cast(_1802.OrderForTE)

        @property
        def harmonic_order_for_te(
            self: "HarmonicOrderForTE._Cast_HarmonicOrderForTE",
        ) -> "HarmonicOrderForTE":
            return self._parent

        def __getattr__(self: "HarmonicOrderForTE._Cast_HarmonicOrderForTE", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "HarmonicOrderForTE.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def harmonic(self: Self) -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Harmonic

        if temp is None:
            return 0

        return temp

    @property
    def cast_to(self: Self) -> "HarmonicOrderForTE._Cast_HarmonicOrderForTE":
        return self._Cast_HarmonicOrderForTE(self)



"""StiffnessSolver"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy.nodal_analysis.system_solvers import _115
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_STIFFNESS_SOLVER = python_net_import(
    "SMT.MastaAPI.NodalAnalysis.SystemSolvers", "StiffnessSolver"
)

if TYPE_CHECKING:
    from mastapy.nodal_analysis.system_solvers import (
        _100,
        _101,
        _103,
        _104,
        _105,
        _106,
        _107,
        _108,
        _109,
        _110,
        _111,
        _116,
        _118,
        _119,
    )


__docformat__ = "restructuredtext en"
__all__ = ("StiffnessSolver",)


Self = TypeVar("Self", bound="StiffnessSolver")


class StiffnessSolver(_115.Solver):
    """StiffnessSolver

    This is a mastapy class.
    """

    TYPE = _STIFFNESS_SOLVER
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_StiffnessSolver")

    class _Cast_StiffnessSolver:
        """Special nested class for casting StiffnessSolver to subclasses."""

        def __init__(
            self: "StiffnessSolver._Cast_StiffnessSolver", parent: "StiffnessSolver"
        ):
            self._parent = parent

        @property
        def solver(self: "StiffnessSolver._Cast_StiffnessSolver") -> "_115.Solver":
            return self._parent._cast(_115.Solver)

        @property
        def backward_euler_acceleration_step_halving_transient_solver(
            self: "StiffnessSolver._Cast_StiffnessSolver",
        ) -> "_100.BackwardEulerAccelerationStepHalvingTransientSolver":
            from mastapy.nodal_analysis.system_solvers import _100

            return self._parent._cast(
                _100.BackwardEulerAccelerationStepHalvingTransientSolver
            )

        @property
        def backward_euler_transient_solver(
            self: "StiffnessSolver._Cast_StiffnessSolver",
        ) -> "_101.BackwardEulerTransientSolver":
            from mastapy.nodal_analysis.system_solvers import _101

            return self._parent._cast(_101.BackwardEulerTransientSolver)

        @property
        def dynamic_solver(
            self: "StiffnessSolver._Cast_StiffnessSolver",
        ) -> "_103.DynamicSolver":
            from mastapy.nodal_analysis.system_solvers import _103

            return self._parent._cast(_103.DynamicSolver)

        @property
        def internal_transient_solver(
            self: "StiffnessSolver._Cast_StiffnessSolver",
        ) -> "_104.InternalTransientSolver":
            from mastapy.nodal_analysis.system_solvers import _104

            return self._parent._cast(_104.InternalTransientSolver)

        @property
        def lobatto_iiia_transient_solver(
            self: "StiffnessSolver._Cast_StiffnessSolver",
        ) -> "_105.LobattoIIIATransientSolver":
            from mastapy.nodal_analysis.system_solvers import _105

            return self._parent._cast(_105.LobattoIIIATransientSolver)

        @property
        def lobatto_iiic_transient_solver(
            self: "StiffnessSolver._Cast_StiffnessSolver",
        ) -> "_106.LobattoIIICTransientSolver":
            from mastapy.nodal_analysis.system_solvers import _106

            return self._parent._cast(_106.LobattoIIICTransientSolver)

        @property
        def newmark_acceleration_transient_solver(
            self: "StiffnessSolver._Cast_StiffnessSolver",
        ) -> "_107.NewmarkAccelerationTransientSolver":
            from mastapy.nodal_analysis.system_solvers import _107

            return self._parent._cast(_107.NewmarkAccelerationTransientSolver)

        @property
        def newmark_transient_solver(
            self: "StiffnessSolver._Cast_StiffnessSolver",
        ) -> "_108.NewmarkTransientSolver":
            from mastapy.nodal_analysis.system_solvers import _108

            return self._parent._cast(_108.NewmarkTransientSolver)

        @property
        def semi_implicit_transient_solver(
            self: "StiffnessSolver._Cast_StiffnessSolver",
        ) -> "_109.SemiImplicitTransientSolver":
            from mastapy.nodal_analysis.system_solvers import _109

            return self._parent._cast(_109.SemiImplicitTransientSolver)

        @property
        def simple_acceleration_based_step_halving_transient_solver(
            self: "StiffnessSolver._Cast_StiffnessSolver",
        ) -> "_110.SimpleAccelerationBasedStepHalvingTransientSolver":
            from mastapy.nodal_analysis.system_solvers import _110

            return self._parent._cast(
                _110.SimpleAccelerationBasedStepHalvingTransientSolver
            )

        @property
        def simple_velocity_based_step_halving_transient_solver(
            self: "StiffnessSolver._Cast_StiffnessSolver",
        ) -> "_111.SimpleVelocityBasedStepHalvingTransientSolver":
            from mastapy.nodal_analysis.system_solvers import _111

            return self._parent._cast(
                _111.SimpleVelocityBasedStepHalvingTransientSolver
            )

        @property
        def step_halving_transient_solver(
            self: "StiffnessSolver._Cast_StiffnessSolver",
        ) -> "_116.StepHalvingTransientSolver":
            from mastapy.nodal_analysis.system_solvers import _116

            return self._parent._cast(_116.StepHalvingTransientSolver)

        @property
        def transient_solver(
            self: "StiffnessSolver._Cast_StiffnessSolver",
        ) -> "_118.TransientSolver":
            from mastapy.nodal_analysis.system_solvers import _118

            return self._parent._cast(_118.TransientSolver)

        @property
        def wilson_theta_transient_solver(
            self: "StiffnessSolver._Cast_StiffnessSolver",
        ) -> "_119.WilsonThetaTransientSolver":
            from mastapy.nodal_analysis.system_solvers import _119

            return self._parent._cast(_119.WilsonThetaTransientSolver)

        @property
        def stiffness_solver(
            self: "StiffnessSolver._Cast_StiffnessSolver",
        ) -> "StiffnessSolver":
            return self._parent

        def __getattr__(self: "StiffnessSolver._Cast_StiffnessSolver", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "StiffnessSolver.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def cast_to(self: Self) -> "StiffnessSolver._Cast_StiffnessSolver":
        return self._Cast_StiffnessSolver(self)



"""BevelGearParametricStudyTool"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.parametric_study_tools import _4301
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_BEVEL_GEAR_PARAMETRIC_STUDY_TOOL = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ParametricStudyTools",
    "BevelGearParametricStudyTool",
)

if TYPE_CHECKING:
    from mastapy.system_model.part_model.gears import _2519
    from mastapy.system_model.analyses_and_results.parametric_study_tools import (
        _4308,
        _4310,
        _4311,
        _4414,
        _4420,
        _4423,
        _4425,
        _4426,
        _4441,
        _4329,
        _4362,
        _4381,
        _4321,
        _4393,
    )
    from mastapy.system_model.analyses_and_results.analysis_cases import _7545
    from mastapy.system_model.analyses_and_results import _2657, _2653, _2651


__docformat__ = "restructuredtext en"
__all__ = ("BevelGearParametricStudyTool",)


Self = TypeVar("Self", bound="BevelGearParametricStudyTool")


class BevelGearParametricStudyTool(_4301.AGMAGleasonConicalGearParametricStudyTool):
    """BevelGearParametricStudyTool

    This is a mastapy class.
    """

    TYPE = _BEVEL_GEAR_PARAMETRIC_STUDY_TOOL
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_BevelGearParametricStudyTool")

    class _Cast_BevelGearParametricStudyTool:
        """Special nested class for casting BevelGearParametricStudyTool to subclasses."""

        def __init__(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
            parent: "BevelGearParametricStudyTool",
        ):
            self._parent = parent

        @property
        def agma_gleason_conical_gear_parametric_study_tool(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_4301.AGMAGleasonConicalGearParametricStudyTool":
            return self._parent._cast(_4301.AGMAGleasonConicalGearParametricStudyTool)

        @property
        def conical_gear_parametric_study_tool(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_4329.ConicalGearParametricStudyTool":
            from mastapy.system_model.analyses_and_results.parametric_study_tools import (
                _4329,
            )

            return self._parent._cast(_4329.ConicalGearParametricStudyTool)

        @property
        def gear_parametric_study_tool(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_4362.GearParametricStudyTool":
            from mastapy.system_model.analyses_and_results.parametric_study_tools import (
                _4362,
            )

            return self._parent._cast(_4362.GearParametricStudyTool)

        @property
        def mountable_component_parametric_study_tool(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_4381.MountableComponentParametricStudyTool":
            from mastapy.system_model.analyses_and_results.parametric_study_tools import (
                _4381,
            )

            return self._parent._cast(_4381.MountableComponentParametricStudyTool)

        @property
        def component_parametric_study_tool(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_4321.ComponentParametricStudyTool":
            from mastapy.system_model.analyses_and_results.parametric_study_tools import (
                _4321,
            )

            return self._parent._cast(_4321.ComponentParametricStudyTool)

        @property
        def part_parametric_study_tool(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_4393.PartParametricStudyTool":
            from mastapy.system_model.analyses_and_results.parametric_study_tools import (
                _4393,
            )

            return self._parent._cast(_4393.PartParametricStudyTool)

        @property
        def part_analysis_case(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_7545.PartAnalysisCase":
            from mastapy.system_model.analyses_and_results.analysis_cases import _7545

            return self._parent._cast(_7545.PartAnalysisCase)

        @property
        def part_analysis(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_2657.PartAnalysis":
            from mastapy.system_model.analyses_and_results import _2657

            return self._parent._cast(_2657.PartAnalysis)

        @property
        def design_entity_single_context_analysis(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_2653.DesignEntitySingleContextAnalysis":
            from mastapy.system_model.analyses_and_results import _2653

            return self._parent._cast(_2653.DesignEntitySingleContextAnalysis)

        @property
        def design_entity_analysis(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_2651.DesignEntityAnalysis":
            from mastapy.system_model.analyses_and_results import _2651

            return self._parent._cast(_2651.DesignEntityAnalysis)

        @property
        def bevel_differential_gear_parametric_study_tool(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_4308.BevelDifferentialGearParametricStudyTool":
            from mastapy.system_model.analyses_and_results.parametric_study_tools import (
                _4308,
            )

            return self._parent._cast(_4308.BevelDifferentialGearParametricStudyTool)

        @property
        def bevel_differential_planet_gear_parametric_study_tool(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_4310.BevelDifferentialPlanetGearParametricStudyTool":
            from mastapy.system_model.analyses_and_results.parametric_study_tools import (
                _4310,
            )

            return self._parent._cast(
                _4310.BevelDifferentialPlanetGearParametricStudyTool
            )

        @property
        def bevel_differential_sun_gear_parametric_study_tool(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_4311.BevelDifferentialSunGearParametricStudyTool":
            from mastapy.system_model.analyses_and_results.parametric_study_tools import (
                _4311,
            )

            return self._parent._cast(_4311.BevelDifferentialSunGearParametricStudyTool)

        @property
        def spiral_bevel_gear_parametric_study_tool(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_4414.SpiralBevelGearParametricStudyTool":
            from mastapy.system_model.analyses_and_results.parametric_study_tools import (
                _4414,
            )

            return self._parent._cast(_4414.SpiralBevelGearParametricStudyTool)

        @property
        def straight_bevel_diff_gear_parametric_study_tool(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_4420.StraightBevelDiffGearParametricStudyTool":
            from mastapy.system_model.analyses_and_results.parametric_study_tools import (
                _4420,
            )

            return self._parent._cast(_4420.StraightBevelDiffGearParametricStudyTool)

        @property
        def straight_bevel_gear_parametric_study_tool(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_4423.StraightBevelGearParametricStudyTool":
            from mastapy.system_model.analyses_and_results.parametric_study_tools import (
                _4423,
            )

            return self._parent._cast(_4423.StraightBevelGearParametricStudyTool)

        @property
        def straight_bevel_planet_gear_parametric_study_tool(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_4425.StraightBevelPlanetGearParametricStudyTool":
            from mastapy.system_model.analyses_and_results.parametric_study_tools import (
                _4425,
            )

            return self._parent._cast(_4425.StraightBevelPlanetGearParametricStudyTool)

        @property
        def straight_bevel_sun_gear_parametric_study_tool(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_4426.StraightBevelSunGearParametricStudyTool":
            from mastapy.system_model.analyses_and_results.parametric_study_tools import (
                _4426,
            )

            return self._parent._cast(_4426.StraightBevelSunGearParametricStudyTool)

        @property
        def zerol_bevel_gear_parametric_study_tool(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "_4441.ZerolBevelGearParametricStudyTool":
            from mastapy.system_model.analyses_and_results.parametric_study_tools import (
                _4441,
            )

            return self._parent._cast(_4441.ZerolBevelGearParametricStudyTool)

        @property
        def bevel_gear_parametric_study_tool(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
        ) -> "BevelGearParametricStudyTool":
            return self._parent

        def __getattr__(
            self: "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "BevelGearParametricStudyTool.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self: Self) -> "_2519.BevelGear":
        """mastapy.system_model.part_model.gears.BevelGear

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: Self,
    ) -> "BevelGearParametricStudyTool._Cast_BevelGearParametricStudyTool":
        return self._Cast_BevelGearParametricStudyTool(self)



"""SquareMatrix"""
from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy.math_utility import _1524
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_SQUARE_MATRIX = python_net_import("SMT.MastaAPI.MathUtility", "SquareMatrix")

if TYPE_CHECKING:
    from mastapy.math_utility import _1513


__docformat__ = "restructuredtext en"
__all__ = ("SquareMatrix",)


Self = TypeVar("Self", bound="SquareMatrix")


class SquareMatrix(_1524.RealMatrix):
    """SquareMatrix

    This is a mastapy class.
    """

    TYPE = _SQUARE_MATRIX
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_SquareMatrix")

    class _Cast_SquareMatrix:
        """Special nested class for casting SquareMatrix to subclasses."""

        def __init__(self: "SquareMatrix._Cast_SquareMatrix", parent: "SquareMatrix"):
            self._parent = parent

        @property
        def real_matrix(self: "SquareMatrix._Cast_SquareMatrix") -> "_1524.RealMatrix":
            return self._parent._cast(_1524.RealMatrix)

        @property
        def generic_matrix(
            self: "SquareMatrix._Cast_SquareMatrix",
        ) -> "_1513.GenericMatrix":
            from mastapy.math_utility import _1513

            return self._parent._cast(_1513.GenericMatrix)

        @property
        def square_matrix(self: "SquareMatrix._Cast_SquareMatrix") -> "SquareMatrix":
            return self._parent

        def __getattr__(self: "SquareMatrix._Cast_SquareMatrix", name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "SquareMatrix.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def cast_to(self: Self) -> "SquareMatrix._Cast_SquareMatrix":
        return self._Cast_SquareMatrix(self)
